"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const index_1 = __importDefault(require("./index"));
const complexObj = {
    foo: "bar",
    bad: "obj",
    this: true,
    me: {
        o: {
            me: {
                o: [true, false, true, null, "this", "that", true, 9],
            },
        },
    },
};
const tests = [
    {
        desc: "get something that does not exist",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield store.get("blahblah");
                (0, chai_1.expect)(res).to.eql(null);
            });
        },
    },
    {
        desc: "save string",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                yield store.save("foo", "hallo");
            });
        },
    },
    {
        desc: "get string",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield store.get("foo");
                (0, chai_1.expect)(typeof res).to.eql("string");
                (0, chai_1.expect)(res).to.eql("hallo");
            });
        },
    },
    {
        desc: "save object",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                yield store.save("foo", { bar: "baz", wang: "bang" });
            });
        },
    },
    {
        desc: "get object",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield store.get("foo");
                (0, chai_1.expect)(typeof res).to.eql("object");
                (0, chai_1.expect)(res).to.eql({ bar: "baz", wang: "bang" });
            });
        },
    },
    {
        desc: "save complex object",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                yield store.save("complex", complexObj);
            });
        },
    },
    {
        desc: "get complex object",
        test: (store) => {
            return () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield store.get("complex");
                (0, chai_1.expect)(typeof res).to.eql("object");
                (0, chai_1.expect)(res).to.eql(complexObj);
            });
        },
    },
];
describe("SecureStore", () => {
    describe("Error handling", () => {
        it("invalid connection config", () => __awaiter(void 0, void 0, void 0, function* () {
            const ss = new index_1.default({
                redis: {
                    url: "redis://127.0.0.1:6378",
                },
            });
            try {
                yield ss.init();
                throw new Error("should not arrive here");
            }
            catch (e) {
                (0, chai_1.expect)(e.toString()).to.eql("Error: connect ECONNREFUSED 127.0.0.1:6378");
            }
        }));
    });
    describe("Client get and save", () => {
        const ss = new index_1.default({
            uid: "ssr-test",
            secret: "823HD8DG26JA0LK1239Hgb651TWfs0j1",
            redis: {
                url: "redis://127.0.0.1:6379",
            },
        });
        describe("First client", () => {
            for (const test of tests) {
                it(test.desc, test.test(ss));
            }
        });
        describe("Second client", () => {
            const ss2 = new index_1.default({
                uid: "ssr-test2",
                secret: "823HD8DG26JA0LK1239Hgb651TWfs0j2",
                redis: {
                    url: "redis://127.0.0.1:6379",
                },
            });
            it("get (wrong store)", () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss2.get("foo");
                (0, chai_1.expect)(res).to.eql(null);
            }));
            after(() => __awaiter(void 0, void 0, void 0, function* () {
                yield ss2.disconnect();
            }));
        });
        after(() => __awaiter(void 0, void 0, void 0, function* () {
            yield ss.disconnect();
        }));
    });
    describe("Invocations", () => {
        it("without uid", () => __awaiter(void 0, void 0, void 0, function* () {
            const store = new index_1.default({
                secret: "dh348djgk548fks83kds8kdsfgssgjfg",
                redis: {
                    url: "redis://127.0.0.1:6379",
                },
            });
            yield store.save("foo", "hello");
            (0, chai_1.expect)(yield store.get("foo")).to.eql("hello");
            yield store.disconnect();
        }));
        it("no clashing", () => __awaiter(void 0, void 0, void 0, function* () {
            const store = new index_1.default({
                redis: {
                    url: "redis://127.0.0.1:6379",
                },
            });
            yield store.save("foo", "hello1");
            (0, chai_1.expect)(yield store.get("foo")).to.eql("hello1");
            const store2 = new index_1.default({
                redis: {
                    url: "redis://127.0.0.1:6379",
                },
            });
            yield store2.save("foo", "hello2");
            (0, chai_1.expect)(yield store2.get("foo")).to.eql("hello2");
            yield store.disconnect();
            yield store2.disconnect();
        }));
    });
    describe("Long UID", () => {
        const ss = new index_1.default({
            uid: "secure-store-redis-test1",
            secret: "823HD8DG26JA0LK1239Hgb651TWfs0j1",
            redis: {
                url: "redis://127.0.0.1:6379",
            },
        });
        describe("First client", () => {
            for (const test of tests) {
                it(test.desc, test.test(ss));
            }
        });
        describe("Second client", () => {
            const ss2 = new index_1.default({
                uid: "secure-store-redis-test2",
                secret: "823HD8DG26JA0LK1239Hgb651TWfs0j2",
                redis: {
                    url: "redis://127.0.0.1:6379",
                },
            });
            it("get (wrong store)", () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss2.get("foo");
                (0, chai_1.expect)(res).to.eql(null);
            }));
            after(() => __awaiter(void 0, void 0, void 0, function* () {
                yield ss2.disconnect();
            }));
        });
        after(() => __awaiter(void 0, void 0, void 0, function* () {
            yield ss.disconnect();
        }));
    });
    describe("README Example", () => {
        const store = new index_1.default({
            uid: "myApp:store",
            secret: "823HD8DG26JA0LK1239Hgb651TWfs0j1",
            redis: {
                url: "redis://localhost:6379",
            },
        });
        describe("First client", () => {
            it("save", () => __awaiter(void 0, void 0, void 0, function* () {
                yield store.save("quote", "hello world");
            }));
            it("get", () => __awaiter(void 0, void 0, void 0, function* () {
                (0, chai_1.expect)(yield store.get("quote")).to.eql("hello world");
            }));
            it("delete", () => __awaiter(void 0, void 0, void 0, function* () {
                (0, chai_1.expect)(yield store.delete("quote")).to.eql(1);
            }));
            it("get deleted item fails", () => __awaiter(void 0, void 0, void 0, function* () {
                (0, chai_1.expect)(yield store.get("quote")).to.eql(null);
            }));
            it("save", () => __awaiter(void 0, void 0, void 0, function* () {
                yield store.save("quote", "hello world again");
            }));
        });
        describe("Second client", () => {
            const ss2 = new index_1.default({
                uid: "myApp:store",
                secret: "this is the wrong secret 32 char",
                redis: {
                    url: "redis://localhost:6379",
                },
            });
            it("get (wrong store)", () => __awaiter(void 0, void 0, void 0, function* () {
                const res = yield ss2.get("quote");
                (0, chai_1.expect)(res).to.eql(null);
            }));
            after(() => __awaiter(void 0, void 0, void 0, function* () {
                yield ss2.disconnect();
            }));
        });
        describe("Third client (same secret)", () => {
            const ss3 = new index_1.default({
                uid: "myApp:store",
                secret: "823HD8DG26JA0LK1239Hgb651TWfs0j1",
                redis: {
                    url: "redis://localhost:6379",
                },
            });
            it("get data from another store", () => __awaiter(void 0, void 0, void 0, function* () {
                (0, chai_1.expect)(yield ss3.get("quote")).to.eql("hello world again");
            }));
            after(() => __awaiter(void 0, void 0, void 0, function* () {
                yield ss3.disconnect();
            }));
        });
        after(() => __awaiter(void 0, void 0, void 0, function* () {
            yield store.disconnect();
        }));
    });
});
//# sourceMappingURL=/index.test.js.map